/*
 *************************************************************************
 * Copyright (c) 2004, 2005 Actuate Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Actuate Corporation  - initial API and implementation
 *  
 *************************************************************************
 */

package org.eclipse.datatools.connectivity.oda.consumer.helper;

import org.eclipse.datatools.connectivity.oda.OdaException;
import org.eclipse.datatools.connectivity.oda.SortSpec;

import com.ibm.icu.util.ULocale;

/**
 * OdaSortSpecHelper is a interface for handling SortSpec's. 
 */
public final class OdaSortSpecHelper
{
	private OdaSortSpecHelper()
	{
		// not meant to be instantiated
	}
	
	public static void addSortKey( OdaQuery statement,
								   String columnName,
								   int sortOrder,
								   String localeString ) throws OdaException
	{
		SortSpec sortSpec = statement.getSortSpec();
		if( sortSpec != null )
		{
			sortSpec.addSortKey( columnName, sortOrder );
			return;
		}

		int sortMode = statement.getDSMetaData().getSortMode();
		sortSpec = new SortSpec( sortMode );
		sortSpec.setLocale( convertToLocale( localeString ) );
		sortSpec.addSortKey( columnName, sortOrder );
		statement.setSortSpec( sortSpec );
	}
	
	public static void addSortKey( OdaAdvancedQuery statement,
								   String resultSetName,
								   String columnName,
								   int sortOrder,
								   String localeString ) throws OdaException
	{
		SortSpec sortSpec = statement.getSortSpec( resultSetName );
		if( sortSpec != null )
		{
			sortSpec.addSortKey( columnName, sortOrder );
			return;
		}
		
		int sortMode = statement.getDSMetaData().getSortMode();
		sortSpec = new SortSpec( sortMode );
		sortSpec.setLocale( convertToLocale( localeString ) );
		sortSpec.addSortKey( columnName, sortOrder );
		statement.setSortSpec( resultSetName, sortSpec );
	}
	
	public static void resetSortKeys( OdaQuery statement ) throws OdaException
	{
		statement.setSortSpec( null );
	}
	
	public static void resetSortKeys( OdaAdvancedQuery statement,
									  String resultSetName ) throws OdaException
	{
		statement.setSortSpec( resultSetName, null );
	}
	
	private static ULocale convertToLocale( String localeString )
	{
		if( localeString == null || localeString.length() != 5 )
			return ULocale.getDefault();
				
		try
		{
			String language = localeString.substring( 0, 2 );
			String country  = localeString.substring( 3, 5 );
			return new ULocale( language, country );
		}
		catch ( Exception e )
		{
			return ULocale.getDefault();
		}
	}
}
