/*******************************************************************************
 * Copyright (c) 2004-2005 Sybase, Inc.
 * 
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: rcernich - initial API and implementation
 ******************************************************************************/
package org.eclipse.datatools.connectivity.operations;

import java.lang.reflect.InvocationTargetException;
import java.util.Properties;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.datatools.connectivity.ConnectionProfileException;
import org.eclipse.datatools.connectivity.ProfileManager;
import org.eclipse.datatools.connectivity.internal.ConnectivityPlugin;
import org.eclipse.jface.operation.IRunnableWithProgress;

/**
 * @author rcernich
 * 
 * Created on Mar 15, 2004
 */
public class CreateProfileOperation implements IRunnableWithProgress {

	private String mId;

	private String mName;

	private String mDescription;

	private Properties mProperties;

	public CreateProfileOperation(String id, String name, String description,
									Properties properties) {
		super();
		mId = id;
		mName = name;
		mDescription = description;
		mProperties = properties;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.operation.IRunnableWithProgress#run(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public void run(IProgressMonitor monitor) throws InvocationTargetException,
			InterruptedException {
		monitor.beginTask(ConnectivityPlugin.getDefault().getResourceString(
				"operation.new.connectionprofile", new Object[] { mName}), 2); //$NON-NLS-1$
		monitor.worked(1);
		try {
			ProfileManager.getInstance().createProfile(mName, mDescription,
					mId, mProperties);
			monitor.worked(1);
			if (monitor.isCanceled())
				throw new InterruptedException();
		}
		catch (ConnectionProfileException e) {
			throw new InvocationTargetException(e);
		}
	}

}