/*******************************************************************************
 * Copyright (c) 2004-2005 Sybase, Inc.
 * 
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: shongxum - initial API and implementation
 ******************************************************************************/
package org.eclipse.datatools.connectivity.ui.dse.actions;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.jobs.IJobChangeEvent;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.core.runtime.jobs.JobChangeAdapter;
import org.eclipse.datatools.connectivity.IConnectionProfile;
import org.eclipse.datatools.connectivity.internal.ConnectionProfile;
import org.eclipse.datatools.connectivity.ui.dse.DSEPlugin;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.IActionDelegate;

/**
 * @author shongxum, brianf
 */
public class ConnectAction implements IActionDelegate {

	IConnectionProfile mProfile = null;
	
	/**
	 * This method blocks until the connection has been created.
	 * 
	 * @param profile
	 * @param viewer
	 * 
	 * @deprecated use IConnectionProfile.connect(). The caller is now
	 *             responsible for updating their view themselves. Note, if you
	 *             are using a servers viewer, you should not need to update the
	 *             view as the view listens for connect events and updates
	 *             itself.
	 */
	public static void connectAndRefresh(IConnectionProfile profile,
			TreeViewer viewer) {
		profile.connect();

		viewer.refresh(profile);
		viewer.setExpandedState(profile, true);
	}

	/**
	 * @param profile
	 * @param contentProvider
	 * @return
	 * @deprecated use IConnectionProfile.connect(). The caller is now
	 *             responsible for updating their view themselves. Note, if you
	 *             are using a servers viewer, you should not need to update the
	 *             view as the view listens for connect events and updates
	 *             itself.
	 */
	public static Job connect(IConnectionProfile profile,
			ITreeContentProvider contentProvider) {
		Job connectJob = ((ConnectionProfile) profile).new ConnectJob();
		connectJob.schedule();
		return connectJob;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		if (mProfile != null) {
			removeOldFailureMarker();
			mProfile.connect(new JobChangeAdapter() {
	
				public void done(IJobChangeEvent event) {
					IStatus result = event.getResult();
					if (result.getSeverity() == IStatus.ERROR) {
						IStatus[] kids = result.getChildren();
						if (kids == null) {
							// BTF: Changes made for CR 401622
							mProfile.disconnect(null);
							addFailureMarker(result);
						}
						else {
							boolean someOK = false;
							for (int index = 0, count = kids.length; index < count; ++index) {
								switch (kids[index].getSeverity()) {
								case IStatus.OK:
								case IStatus.INFO:
								case IStatus.WARNING:
									someOK = true;
									break;
								case IStatus.ERROR:
									addFailureMarker(kids[index]);
									break;
								}
							}
							if (!someOK) {
								mProfile.disconnect(null);
							}
						}
					}
				}
			});
		}
	}

	private void addFailureMarker(IStatus result) {
		IResource resource = ResourcesPlugin.getWorkspace().getRoot();
		Map map = new HashMap(3);
		map.put(IMarker.MESSAGE, DSEPlugin.getDefault().getResourceString(
				"error.connect", new String[] { mProfile.getName(),result.getMessage()})); //$NON-NLS-1$
		map.put(IMarker.SEVERITY, new Integer(IMarker.SEVERITY_ERROR));
		map.put(IMarker.LOCATION, mProfile.getName());
		map.put(IMarker.TRANSIENT, Boolean.TRUE.toString());

		try {
			IMarker marker = resource
					.createMarker("org.eclipse.datatools.connectivity.profileFailure"); //$NON-NLS-1$
			marker.setAttributes(map);
		}
		catch (CoreException e) {
		}
	}

	private void removeOldFailureMarker() {
		IResource resource = ResourcesPlugin.getWorkspace().getRoot();
		try {
			IMarker[] markers = resource.findMarkers(
					"org.eclipse.datatools.connectivity.profileFailure", true, //$NON-NLS-1$
					IResource.DEPTH_INFINITE);
			for (int i = 0; i < markers.length; i++) {
				if (markers[i].getAttribute(IMarker.LOCATION, new String())
						.equals(mProfile.getName())) {
					markers[i].delete();
				}
			}
		}
		catch (CoreException e) {
		}
	}

	public void selectionChanged(IAction action, ISelection selection) {
		mProfile = null;
		IStructuredSelection sel = (IStructuredSelection) selection;
		if (sel.getFirstElement() instanceof IConnectionProfile) {
			IConnectionProfile profile = (IConnectionProfile) sel.getFirstElement();
			action.setEnabled(!profile.isConnected());
			mProfile = profile;
		}
	}

}