/*******************************************************************************
 * Copyright (c) 2004-2005 Sybase, Inc.
 * 
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: shongxum - initial API and implementation
 ******************************************************************************/
package org.eclipse.datatools.connectivity.ui.dse.actions;

import java.util.Iterator;

import org.eclipse.datatools.connectivity.ConnectionProfileException;
import org.eclipse.datatools.connectivity.IConnectionProfile;
import org.eclipse.datatools.connectivity.ProfileManager;
import org.eclipse.datatools.connectivity.internal.ui.dialogs.ExceptionHandler;
import org.eclipse.datatools.connectivity.ui.dse.DSEPlugin;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IActionDelegate;

/**
 * @author shongxum, brianf
 */
public class DeleteAction implements IActionDelegate {

	private Shell mParentShell = null;
	private Iterator mIterator = null;

	/**
	 * 
	 */
	public DeleteAction() {
		Display display = Display.getCurrent();
		mParentShell = display.getActiveShell();

	}
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		Object object;
		IConnectionProfile profile;
		while (mIterator != null && mIterator.hasNext()) {
			object = mIterator.next();
			if (object instanceof IConnectionProfile) {
				profile = (IConnectionProfile) object;
			}
			else {
				continue;
			}

			boolean ret = MessageDialog.openQuestion(mParentShell,
					DSEPlugin.getDefault().getResourceString(
							"actions.delete.title"), DSEPlugin //$NON-NLS-1$
							.getDefault().getResourceString(
									"actions.delete.confirm", //$NON-NLS-1$
									new String[] { profile.getName()}));
			if (!ret)
				return;
			try {
				ProfileManager.getInstance().deleteProfile(profile);
			}
			catch (ConnectionProfileException e) {
				ExceptionHandler.showException(mParentShell,
						DSEPlugin.getDefault().getResourceString(
								"dialog.title.error"), e //$NON-NLS-1$
								.getMessage(), e);
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		mIterator = null;
		if (selection instanceof IStructuredSelection) {
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			action.setEnabled(structuredSelection.size() > 0);
			if (structuredSelection.size() > 0) {
				mIterator = structuredSelection.iterator();
			}
		}
	}
}