/*******************************************************************************
 * Copyright (c) 2004-2005 Sybase, Inc.
 * 
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: shongxum - initial API and implementation
 ******************************************************************************/
package org.eclipse.datatools.connectivity.ui.dse.actions;

import org.eclipse.datatools.connectivity.ConnectionProfileException;
import org.eclipse.datatools.connectivity.IConnectionProfile;
import org.eclipse.datatools.connectivity.ProfileManager;
import org.eclipse.datatools.connectivity.internal.ui.dialogs.ExceptionHandler;
import org.eclipse.datatools.connectivity.ui.dse.DSEPlugin;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IActionDelegate;

/**
 * @author shongxum, brianf
 */
public class RenameAction implements IActionDelegate {

	private Shell mParentShell;

	private IConnectionProfile mProfile;

	public RenameAction() {
		Display display = Display.getCurrent();
		mParentShell = display.getActiveShell();
	}
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		IInputValidator inputValidator = new IInputValidator() {

			public String isValid(String newText) {
				if (newText == null || newText.trim().length() == 0) {
					return DSEPlugin.getDefault().getResourceString(
							"rename.dialog.errmsg.invalid"); //$NON-NLS-1$
				}
				else if (nameExisting(newText)) {
					return DSEPlugin.getDefault().getResourceString(
							"rename.dialog.errmsg.existing"); //$NON-NLS-1$                    
				}
				else {
					return null;
				}
			}
		};
		InputDialog d = new InputDialog(
				mParentShell,
				DSEPlugin.getDefault().getResourceString(
						"rename.dialog.title"), //$NON-NLS-1$
				DSEPlugin.getDefault().getResourceString(
						"rename.dialog.message"), mProfile.getName(), inputValidator); //$NON-NLS-1$
		if (d.open() != Window.OK)
			return;

		try {
			ProfileManager.getInstance().modifyProfile(mProfile, d.getValue(),
					null);
		}
		catch (ConnectionProfileException e) {
			ExceptionHandler.showException(mParentShell, DSEPlugin
					.getDefault().getResourceString("dialog.title.error"), e //$NON-NLS-1$
					.getMessage(), e);
		}
	}

	/**
	 * @param newName
	 * @return
	 */
	private boolean nameExisting(String newName) {
		IConnectionProfile[] profiles = ProfileManager.getInstance()
				.getProfiles();
		for (int i = 0; i < profiles.length; i++) {
			if (profiles[i].getName().equals(newName))
				return true;
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		mProfile = null;
		if (selection instanceof IStructuredSelection) {
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			action.setEnabled(false);
			if (structuredSelection.size() == 1) {
				Object selectedResource = structuredSelection.getFirstElement();
				action.setEnabled(selectedResource instanceof IConnectionProfile);
				if (selectedResource instanceof IConnectionProfile)
					mProfile = (IConnectionProfile) selectedResource;
			}
		}
	}

}