/*******************************************************************************
 * Copyright (c) 2005 Sybase, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Sybase, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.result.internal.preference;

import org.eclipse.datatools.sqltools.result.internal.PreferenceConstants;
import org.eclipse.datatools.sqltools.result.internal.ResultsViewPlugin;
import org.eclipse.datatools.sqltools.result.internal.utils.Messages;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

/**
 * Result history options preference page
 * 
 * @author Dafan Yang
 */
public class ResultHistoryPage extends PreferencePage implements IWorkbenchPreferencePage
{
    private Group     _columnsGroup;
    private Button    _statusColumn;
    private Button    _operColumn;
    private Button    _freqColumn;
    private Button    _dateColumn;
    private Button    _actionColumn;
    private Button    _consumerColumn;
    private Button    _profileColumn;
    private Composite _otherComp;
    private Button    _autoSaveHistory;
    
    protected Control createContents(Composite parent)
    {
        Composite comp = new Composite(parent, SWT.NONE);
        GridLayout layout = new GridLayout();
        layout.numColumns = 1;
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        comp.setLayout(layout);
        
        _columnsGroup = new Group(comp, SWT.NONE);
        _columnsGroup.setText(Messages.getString("ResultHistoryPage.columns.group.name")); //$NON-NLS-1$
        _columnsGroup.setLayout(new GridLayout());
        _columnsGroup.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        
        _statusColumn = new Button(_columnsGroup, SWT.CHECK);
        _statusColumn.setText(Messages.getString("ResultHistoryPage.status")); //$NON-NLS-1$
        _statusColumn.setToolTipText("Check to show 'Status' column");
        
        _operColumn = new Button(_columnsGroup, SWT.CHECK);
        _operColumn.setText(Messages.getString("ResultHistoryPage.operation")); //$NON-NLS-1$
        _operColumn.setToolTipText("Check to show 'Operation' column");
        
        _freqColumn = new Button(_columnsGroup, SWT.CHECK);
        _freqColumn.setText(Messages.getString("ResultHistoryPage.frequency")); //$NON-NLS-1$
        _freqColumn.setToolTipText("Check to show 'Frequency' column");
        
        _dateColumn = new Button(_columnsGroup, SWT.CHECK);
        _dateColumn.setText(Messages.getString("ResultHistoryPage.date")); //$NON-NLS-1$
        _dateColumn.setToolTipText("Check to show 'Date' column");
        
        _actionColumn = new Button(_columnsGroup, SWT.CHECK);
        _actionColumn.setText(Messages.getString("ResultHistoryPage.action.type")); //$NON-NLS-1$
        _actionColumn.setToolTipText("Check to show 'Action Type' column");
        
        _consumerColumn = new Button(_columnsGroup, SWT.CHECK);
        _consumerColumn.setText(Messages.getString("ResultHistoryPage.consumer.name")); //$NON-NLS-1$
        _consumerColumn.setToolTipText("Check to show 'Consumer Name' column");
        
        _profileColumn = new Button(_columnsGroup, SWT.CHECK);
        _profileColumn.setText(Messages.getString("ResultHistoryPage.connection.profile")); //$NON-NLS-1$
        _profileColumn.setToolTipText("Check to show 'Connection Profile' column");
        
        new Label(comp, SWT.NONE);
        
        _otherComp = new Composite(comp, SWT.NONE);
        layout = new GridLayout();
        layout.numColumns = 1;
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        
        _otherComp.setLayout(layout);
        _otherComp.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        
        _autoSaveHistory = new Button(_otherComp, SWT.CHECK);
        _autoSaveHistory.setText("Automatically persist result history");
        _autoSaveHistory.setToolTipText("Save result history when Eclipse shuts down and load result history to SQL Results view when Eclipse starts up ");
        
        initializeValues();
        return comp;
    }

    public void init(IWorkbench workbench)
    {
        setPreferenceStore(ResultsViewPlugin.getDefault().getPreferenceStore());        
    }

    private void initializeValues()
    {
        IPreferenceStore store = getPreferenceStore();
        _statusColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_STATUS_COLUMN));
        _operColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_OPER_COLUMN));
        _freqColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_FREQ_COLUMN));
        _dateColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_DATE_COLUMN));
        _actionColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_ACTION_COLUMN));
        _consumerColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_CONSUMER_COLUMN));
        _profileColumn.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_PROFILE_COLUMN));
        _autoSaveHistory.setSelection(store.getBoolean(PreferenceConstants.RESULT_HISTORY_SAVE_HISTORY));
    }
    
    protected void performDefaults()
    {
        IPreferenceStore store = getPreferenceStore();
        _statusColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_STATUS_COLUMN));
        _operColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_OPER_COLUMN));
        _freqColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_FREQ_COLUMN));
        _dateColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_DATE_COLUMN));
        _actionColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_ACTION_COLUMN));
        _consumerColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_CONSUMER_COLUMN));
        _profileColumn.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_PROFILE_COLUMN));
        _autoSaveHistory.setSelection(store.getDefaultBoolean(PreferenceConstants.RESULT_HISTORY_SAVE_HISTORY));
        
        super.performDefaults();
    }

    public boolean performOk()
    {
        IPreferenceStore store = getPreferenceStore();
        store.setValue(PreferenceConstants.RESULT_HISTORY_STATUS_COLUMN, _statusColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_OPER_COLUMN, _operColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_FREQ_COLUMN, _freqColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_DATE_COLUMN, _dateColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_ACTION_COLUMN, _actionColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_CONSUMER_COLUMN, _consumerColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_PROFILE_COLUMN, _profileColumn.getSelection());
        store.setValue(PreferenceConstants.RESULT_HISTORY_SAVE_HISTORY, _autoSaveHistory.getSelection());
        
        return super.performOk();
    } 
}
