/*******************************************************************************
 * Copyright (c) 2004, 2005 Sybase, Inc. and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Sybase, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.routineeditor.internal;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.datatools.sqltools.routineeditor.ProcEditorInput;
import org.eclipse.datatools.sqltools.routineeditor.ui.actions.RunAction;
import org.eclipse.datatools.sqltools.sqleditor.SQLEditor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.Separator;

/**
 * A SQL Editor handles routine objects including stored procedure, function,
 * trigger, and event.
 * 
 * @see org.eclipse.datatools.modelbase.sql.routines.Routine
 * @author Hui Cao
 * 
 */
public class RoutineEditor extends SQLEditor {

	public static final String EDITOR_ID = RoutineEditorActivator.PLUGIN_ID + ".internal.RoutineEditor";

	public RoutineEditor() {
		super();
	}

	protected void initializeEditor() {
		super.initializeEditor();
		setDocumentProvider(RoutineEditorDocumentProviderFactory
				.getDocumentProvider(getEditorInput()));
	}

	protected void createActions() {
		super.createActions();
		// TODO add debug action
		 IAction a = new RunAction(this);
		 setAction( "RunAction", a ); //$NON-NLS-1$
	}

	protected void editorContextMenuAboutToShow(IMenuManager menu) {
		super.editorContextMenuAboutToShow(menu);
		// TODO add debug action
		 menu.add( new Separator() );
		 addAction( menu, "RunAction" ); //$NON-NLS-1$
	}

    public void doSave(IProgressMonitor monitor)
    {
    	//This is caused by closing the connection profile without saving the routine
        if (getEditorInput() instanceof ProcEditorInput && !getConnectionInfo().getConnectionProfile().isConnected())
        {
            doSaveAs();
        }
        else
        {
            super.doSave(monitor);
        }
    }
	
}
