/*******************************************************************************
 * Copyright (c) 2004, 2005 Sybase, Inc. and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Sybase, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.routineeditor.parameter;

import org.eclipse.datatools.sqltools.core.ISqlDataValidator;
import org.eclipse.datatools.sqltools.core.SQLToolsFacade;
import org.eclipse.datatools.sqltools.core.dbitem.ParameterDescriptor;
import org.eclipse.jface.util.ListenerList;

/**
 * @author Yang Liu
 */
public class ParameterWrapper implements IParamManager
{
    ParameterDescriptor _pd;

    private boolean     _isnull    = true;

    private String      _value     = null;

    ListenerList        _listeners = new ListenerList();

    private String      _message     = null;

    private int _status = 0;

    //private String 
    /**
     *  
     */
    public ParameterWrapper(ParameterDescriptor pd)
    {
        this._pd = pd;
    }

    /**
     * @return
     */
    public ParameterDescriptor getParameterDescriptor()
    {
        // TODO Auto-generated method stub
        return _pd;
    }

    /**
     * @return
     */
    public String getValue()
    {
        return _value;
    }

    /**
     * The value will be converted to proper format. If it's invalid, use getMessage() to get the error message.
     * @param value
     */
    public void setValue(String value)
    {

        String converted = value;
        _value = validate(value);
        fireAllUpdated(_pd, _value);
    }

    public boolean isNull()
    {
        return _isnull;
    }

    public void setNull(boolean b)
    {
        _isnull = b;
        //here, the message should not be set as null,because null value doesn't means it will pass validation.
        //_message = _isnull? null: _message;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sybase.stf.dmp.ui.sql.IParamManager#addResultManagerListener(com.sybase.stf.dmp.ui.sql.IParamManagerListener)
     */
    public void addParamManagerListener(IParamManagerListener listener)
    {
        _listeners.add(listener);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.sybase.stf.dmp.ui.sql.IParamManager#removeResultManagerListener(com.sybase.stf.dmp.ui.sql.IParamManagerListener)
     */
    public void removeParamManagerListener(IParamManagerListener listener)
    {
        _listeners.remove(listener);
    }

    protected void fireAllUpdated(ParameterDescriptor pd, String value)
    {
        Object[] listeners = this._listeners.getListeners();
        for (int i = 0; i < listeners.length; i++)
        {
            ((IParamManagerListener) listeners[i]).ParamValueUpdate(pd, value);
        }
    }


    /**
     * @return Returns the error message.
     */
    public String getMessage()
    {
        return _message;
    }

    public void setStatus(int status)
    {
        this._status = status;
    }

    /**
     * @param _message The error message to set.
     */
    public void setMessage(String _message)
    {
        this._message = _message;
    }
    /**
     * Here we should use special validator to validate the value.
     * Then we set the errorMessage according to the status.
     * 
     * @param value
     * @return
     */
    private String validate(String value)
    {
        String result = null;
        try
        {
            ISqlDataValidator validator = SQLToolsFacade.getConfiguration(_pd.getDatabaseIdentifier(), null).getSQLDataService().getSQLDataValidator(_pd.getDatabaseIdentifier());
            if (validator == null)
            {
            	return value;
            }
            _status = validator.validate(_pd.getTypeName(),value);
            switch(_status)
            {
                case ISqlDataValidator.VALIDATE_SUCCESS:
                    {
                        result = validator.getConvertedValue();
                        this.setMessage(null);
                        break;
                    }
                case ISqlDataValidator.VALIDATE_FAIL_CONVERT_SUCCESS:
                    {
                        result = validator.getConvertedValue();
                        this.setMessage(validator.getErrorMessage());
                        break;
                    }
                case ISqlDataValidator.CONVERT_FAIL:
                    {
                        result = value;
                        this.setMessage(validator.getErrorMessage());
                        break;
                    }
                case ISqlDataValidator.SYS_ERROR:
                    {
                        result = value;
                        this.setMessage(validator.getErrorMessage());
                        break;
                    }
            }
        }
        catch (Exception e)
        {
            String errormes = e.getLocalizedMessage();
            errormes = errormes == null?"":errormes ;
            int i = errormes.lastIndexOf(":"); //$NON-NLS-1$
            if (i > 0)
            {
                errormes = errormes.substring(i + 1, errormes.length());
            }
            this.setMessage(this.getMessage()+errormes);
        }
        return result;
    }
    /**
     * @return Returns the _status.
     */
    public int getStatus()
    {
        return _status;
    }
}
