/*******************************************************************************
 * Copyright (c) 2004, 2005 Sybase, Inc. and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Sybase, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.routineeditor.ui.actions;

import org.eclipse.datatools.connectivity.IConnectionProfile;
import org.eclipse.datatools.connectivity.sqm.internal.core.connection.ConnectionInfo;
import org.eclipse.datatools.connectivity.sqm.internal.core.connection.ConnectionInfoImpl;
import org.eclipse.datatools.connectivity.sqm.internal.core.connection.DatabaseConnectionRegistry;
import org.eclipse.datatools.modelbase.sql.routines.Routine;
import org.eclipse.datatools.modelbase.sql.schema.Database;
import org.eclipse.datatools.modelbase.sql.schema.SQLObject;
import org.eclipse.datatools.modelbase.sql.tables.Trigger;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IActionDelegate;

/**
 * 
 * @author Hui Cao
 * 
 */
public abstract class RoutineAction extends Action implements IActionDelegate {

	protected SQLObject _routine = null;

	protected Database _database = null;

	protected IConnectionProfile _connectionProfile = null;

	/**
	 * 
	 */
	public RoutineAction() {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		_connectionProfile = null;
		_routine = null;
		_database = null;
		if (selection instanceof IStructuredSelection) {
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			if (structuredSelection.size() == 1) {
				Object selectedResource = structuredSelection.getFirstElement();
				if (selectedResource instanceof Trigger) {
					_routine = (Trigger) selectedResource;
					_database = ((Trigger) selectedResource).getSchema()
							.getDatabase();
					action.setEnabled(true);
				} else if (selectedResource instanceof Routine) {
					_routine = (Routine) selectedResource;
					_database = ((Routine) selectedResource).getSchema()
							.getDatabase();
					action.setEnabled(true);
				}
				// TODO check Routine.sourceVisible
				// while (selectedResource != null && ! selectedResource
				// instanceof
				// IConnectionProfile )
				// {
				// selectedResource = selectedResource.
				// }
			}
		}
		if (_database != null) {
			ConnectionInfo connInfo = DatabaseConnectionRegistry.getInstance()
					.getConnectionForDatabase(_database);
			if (connInfo instanceof ConnectionInfoImpl) {
				_connectionProfile = ((ConnectionInfoImpl) connInfo)
						.getConnectionProfile();
			}
		}

	}
}