/*******************************************************************************
 * Copyright (c) 2004, 2005 Sybase, Inc. and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Sybase, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.sqltools.routineeditor.ui.actions;

import org.eclipse.datatools.sqltools.core.DatabaseIdentifier;
import org.eclipse.datatools.sqltools.core.ProcIdentifier;
import org.eclipse.datatools.sqltools.internal.SQLDevToolsUtil;
import org.eclipse.datatools.sqltools.routineeditor.ProcEditorInput;
import org.eclipse.datatools.sqltools.routineeditor.internal.RoutineEditor;
import org.eclipse.datatools.sqltools.routineeditor.internal.RoutineEditorActivator;
import org.eclipse.datatools.sqltools.routineeditor.ui.launching.SPLaunchShortcut;
import org.eclipse.datatools.sqltools.sqleditor.ISQLEditorActionConstants;
import org.eclipse.datatools.sqltools.sqleditor.internal.IHelpContextIds;
import org.eclipse.debug.core.ILaunchManager;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

/**
 * 
 * @author Hui Cao
 * 
 */
public class RunAction extends RoutineAction implements IActionDelegate 
{
    private RoutineEditor     _sqlEditor;


    /**
	 * Constructs a default <code>RunAction</code>. This happens
	 * when user invokes the context menu in DSE.
	 */
    public RunAction()
    {
    	this(null);
    }

    /**
     * Constructs a <code>RunAction</code> from a RoutineEditor. This happens
     * when user invokes the context menu in RoutineEditor
     */
    public RunAction(RoutineEditor targetEditor)
    {
    	setText(Messages.getString("RunAction.label"));//$NON-NLS-1$
    	setToolTipText(Messages.getString("RunAction.tooltip"));//$NON-NLS-1$
    	setActionDefinitionId(ISQLEditorActionConstants.RUN_ACTION_ID);
    	setActiveEditor(targetEditor);
    	update();
    	
    	PlatformUI.getWorkbench().getHelpSystem().setHelp(this, IHelpContextIds.RUN_ACTION);
    }
    
    public void setActiveEditor(RoutineEditor targetEditor)
    {
        _sqlEditor = targetEditor;
    }

    public void run()
    {
    	run(null);
    }

    public void update()
    {
        setEnabled(_sqlEditor != null || _routine != null);
    }

	public void run(IAction action) {
		ProcIdentifier proc = null;
        if (_sqlEditor == null || _sqlEditor.getEditorInput() == null)
        {
            try
            {
    			proc = SQLDevToolsUtil.getProcIdentifier(
    					new DatabaseIdentifier(_connectionProfile.getName(),
    							_database.getName()), _routine);
    			IWorkbenchPage page = PlatformUI.getWorkbench()
    					.getActiveWorkbenchWindow().getActivePage();
    			page.openEditor(new ProcEditorInput(proc),
    						RoutineEditor.EDITOR_ID);
            }
            catch (Exception e)
            {
            	RoutineEditorActivator.getDefault().log(e);
            }
        }
        else
        {
        	ProcEditorInput procEditorInput = (ProcEditorInput) _sqlEditor.getEditorInput();
        	proc = procEditorInput.getProcIdentifier();
        }
        if (proc != null)
        {
        	try
        	{
        		SPLaunchShortcut.launch( proc, ILaunchManager.RUN_MODE);
        	}
        	catch (Exception e)
        	{
        		RoutineEditorActivator.getDefault().log(e);
        	}
        	
        }
		
	}

	
}
